@@ -5,6 +5,8 @@
 #'
 #' @param y input vector
 #'
+#' @noRd
+#'
 # -------------------------------------------------------------------------------------------------
 na.zero <- function (y) {
     y[is.na(y)] <- 0
@@ -16,13 +18,13 @@ na.zero <- function (y) {
 # -------------------------------------------------------------------------------------------------
 #' byars_lower
 #'
-#' Calculates the lower confidence limits for observed numbers of events using Byar's method [1].
+#' Calculates the lower confidence limits for observed numbers of events using Byar's method (1).
 #'
 #' @param x the observed numbers of events; numeric vector; no default
 #'
 #' @inheritParams phe_dsr
 #'
-#' @return Returns lower confidence limits for observed numbers of events using Byar's method [1]
+#' @return Returns lower confidence limits for observed numbers of events using Byar's method (1)
 #'
 #' @section Notes: This is an internal package function that is appropriately called by exported
 #'  'phe_' prefixed functions within the PHEindicatormethods package.  \cr \cr
@@ -34,11 +36,11 @@ na.zero <- function (y) {
 #'  Byar's method is inaccurate and may return a negative number - in these cases an error is returned.
 #'
 #' @references
-#' [1] Breslow NE, Day NE. Statistical methods in cancer research,
+#' (1) Breslow NE, Day NE. Statistical methods in cancer research,
 #'  volume II: The design and analysis of cohort studies. Lyon: International
 #'  Agency for Research on Cancer, World Health Organisation; 1987.
-#'
-#' -------------------------------------------------------------------------------------------------
+#
+# -------------------------------------------------------------------------------------------------
 
 # create function to calculate Byar's lower CI limit
 byars_lower <- function(x, confidence = 0.95) {
@@ -72,13 +74,13 @@ byars_lower <- function(x, confidence = 0.95) {
 # -------------------------------------------------------------------------------------------------
 #' byars_upper
 #'
-#' Calculates the upper confidence limits for observed numbers of events using Byar's method [1].
+#' Calculates the upper confidence limits for observed numbers of events using Byar's method (1).
 #'
 #' @param x the observed numbers of events; numeric vector; no default
 #'
 #' @inheritParams phe_dsr
 #'
-#' @return Returns upper confidence limits for observed numbers of events using Byar's method [1]
+#' @return Returns upper confidence limits for observed numbers of events using Byar's method (1)
 #'
 #' @section Notes: This is an internal package function that is appropriately called by exported
 #'  'phe_' prefixed functions within the PHEindicatormethods package.  \cr \cr
@@ -88,11 +90,11 @@ byars_lower <- function(x, confidence = 0.95) {
 #'  will be below the true underlying value, is \eqn{\alpha}/2.
 #'
 #' @references
-#' [1] Breslow NE, Day NE. Statistical methods in cancer research,
+#' (1) Breslow NE, Day NE. Statistical methods in cancer research,
 #'  volume II: The design and analysis of cohort studies. Lyon: International
 #'  Agency for Research on Cancer, World Health Organisation; 1987.
 #'
-#' -------------------------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------------------------
 
 # create function to calculate Byar's upper CI limit
 byars_upper <- function(x, confidence = 0.95) {
@@ -120,14 +122,14 @@ byars_upper <- function(x, confidence = 0.95) {
 # -------------------------------------------------------------------------------------------------
 #' wilson_lower
 #'
-#' Calculates lower confidence limits for observed numbers of events using the Wilson Score method [1,2].
+#' Calculates lower confidence limits for observed numbers of events using the Wilson Score method (1,2).
 #'
 #' @param x the observed numbers of cases in the samples meeting the required condition; numeric vector; no default
 #' @param n the numbers of cases in the samples; numeric vector; no default
 #'
 #' @inheritParams phe_dsr
 #'
-#' @return Returns lower confidence limits for observed numbers of events using the Wilson Score method [1,2]
+#' @return Returns lower confidence limits for observed numbers of events using the Wilson Score method (1,2)
 #'
 #' @section Notes: This is an internal package function that is appropriately called by exported
 #'  'phe_' prefixed functions within the PHEindicatormethods package.  \cr \cr
@@ -136,13 +138,13 @@ byars_upper <- function(x, confidence = 0.95) {
 #'  will be above the true underlying value, is \eqn{\alpha}/2.#'
 #'
 #' @references
-#' [1] Wilson EB. Probable inference, the law of succession, and statistical
+#' (1) Wilson EB. Probable inference, the law of succession, and statistical
 #'  inference. J Am Stat Assoc; 1927; 22. Pg 209 to 212. \cr
-#' [2] Newcombe RG, Altman DG. Proportions and their differences. In Altman
+#' (2) Newcombe RG, Altman DG. Proportions and their differences. In Altman
 #'  DG et al. (eds). Statistics with confidence (2nd edn). London: BMJ Books;
 #'  2000. Pg 46 to 48.
 #'
-#' ------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------------------------
 
 # create function to calculate Wilson's lower CI limit
 wilson_lower <- function(x, n, confidence = 0.95) {
@@ -180,14 +182,14 @@ wilson_lower <- function(x, n, confidence = 0.95) {
 # -------------------------------------------------------------------------------------------------
 #' wilson_upper
 #'
-#' Calculates upper confidence limits for observed numbers of events using the Wilson Score method [1,2].
+#' Calculates upper confidence limits for observed numbers of events using the Wilson Score method (1,2).
 #'
 #' @param x the observed numbers of cases in the samples meeting the required condition; numeric vector; no default
 #' @param n the numbers of cases in the samples; numeric vector; no default
 #'
 #' @inheritParams phe_dsr
 #'
-#' @return Returns upper confidence limits for observed numbers of events using the Wilson Score method [1,2]
+#' @return Returns upper confidence limits for observed numbers of events using the Wilson Score method (1,2)
 #'
 #' @section Notes: This is an internal package function that is appropriately called by exported
 #'  'phe_' prefixed functions within the PHEindicatormethods package.  \cr \cr
@@ -196,13 +198,13 @@ wilson_lower <- function(x, n, confidence = 0.95) {
 #'  will be below the true underlying value, is \eqn{\alpha}/2.#'
 #'
 #' @references
-#' [1] Wilson EB. Probable inference, the law of succession, and statistical
+#' (1) Wilson EB. Probable inference, the law of succession, and statistical
 #'  inference. J Am Stat Assoc; 1927; 22. Pg 209 to 212. \cr
-#' [2] Newcombe RG, Altman DG. Proportions and their differences. In Altman
+#' (2) Newcombe RG, Altman DG. Proportions and their differences. In Altman
 #'  DG et al. (eds). Statistics with confidence (2nd edn). London: BMJ Books;
 #'  2000. Pg 46 to 48.
 #'
-#' ------------------------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------------------------
 
 # create function to calculate Wilson's lower CI limit
 wilson_upper <- function(x, n, confidence = 0.95) {
@@ -244,6 +246,9 @@ wilson_upper <- function(x, n, confidence = 0.95) {
 #'        populations; unquoted string; no default
 #' @param no_quantiles number of quantiles supplied in dataset for SII;
 #'        integer; no default
+#'
+#' @noRd
+#'
 # -------------------------------------------------------------------------------------------------
 
 FindXValues <- function(xvals, no_quantiles){
@@ -304,6 +309,8 @@ FindXValues <- function(xvals, no_quantiles){
 #'        of once and return the Mean Average Difference between the first and subsequent samples (as a
 #'        measure of the amount of variation); logical; default FALSE
 #'
+#' @noRd
+#'
 # -------------------------------------------------------------------------------------------------
 
 SimulationFunc <- function(data,
@@ -522,3 +529,176 @@ SimulationFunc <- function(data,
   return(data.frame(results))
 
 }
+
+
+# ------------------------------------------------------------------------------
+#' Poisson Function for funnel plots for ratios and rates
+#'
+#' @noRd
+#'
+# ------------------------------------------------------------------------------
+
+
+poisson_cis <- function(z, x_a, x_b) {
+  # none of the following can occur based on Funnels.R
+  # if (any(z < 0, x_a < 0, x_b < 0, x_b < x_a, x_a %% 1 > 0, x_b %% 1 > 0))
+  #   return(NA)
+
+  q <- 1
+  tot <- 0
+  s <- 0
+  k <- 0
+
+  while (any(k <= z, q > tot * 1e-10)) {
+    tot <- tot + q
+    if (k >= x_a & k <= x_b) s <- s + q
+    if (tot > 1e30) {
+      s <- s / 1e30
+      tot <- tot / 1e30
+      q <- q / 1e30
+    }
+
+    k <- k + 1
+    q <- q * z / k
+
+  }
+  return(s / tot)
+}
+
+
+# ------------------------------------------------------------------------------
+#' Function for funnel plots for ratios and rates
+#'
+#' @noRd
+#'
+# ------------------------------------------------------------------------------
+
+poisson_funnel <- function(obs, p, side) {
+  # None of the following can occur based on Funnels.R
+  # if (any(obs < 0, p < 0, p > 1, obs %% 1 != 0)) return(NA)
+
+  v <- 0.5
+  dv <- 0.5
+
+  if (side == "low") {
+
+    # this is in the Excel macro code, but obs can't be 0 based on Funnels.R
+    # if (obs == 0) return(0)
+
+    while (dv > 1e-7) {
+      dv <- dv / 2
+
+      if (poisson_cis((1 + obs) * v / (1 - v),
+                      obs,
+                      10000000000) > p) {
+        v <- v - dv
+      } else {
+        v <- v + dv
+      }
+    }
+  } else if (side == "high") {
+
+    while (dv > 1e-7) {
+      dv <- dv / 2
+      if (poisson_cis((1 + obs) * v / (1 - v),
+                      0,
+                      obs) < p) {
+        v <- v - dv
+      } else {
+        v <- v + dv
+      }
+    }
+
+  }
+  p <- (1 + obs) * v / (1 - v)
+  return(p)
+}
+
+# ------------------------------------------------------------------------------
+#' Function for funnel plots for rates and ratios
+#'
+#' @noRd
+#'
+# ------------------------------------------------------------------------------
+
+
+funnel_ratio_significance <- function(obs, expected, p, side) {
+  if (obs == 0 & side == "low") {
+    test_statistic <- 0
+  } else if (obs < 10) {
+    if (side == "low") {
+      degree_freedom <- 2 * obs
+      lower_tail_setting <- FALSE
+    } else if (side == "high") {
+      degree_freedom <- 2 * obs + 2
+      lower_tail_setting <- TRUE
+    }
+
+    test_statistic <- qchisq(p = 0.5 + p / 2,
+                             df = degree_freedom,
+                             lower.tail = lower_tail_setting) / 2
+  } else {
+    if (side == "low") {
+      obs_adjusted <- obs
+      test_statistic <- obs_adjusted * (1 - 1 / (9 * obs_adjusted) -
+                                          qnorm(0.5 + p / 2) / 3 / sqrt(obs_adjusted))^3
+    } else if (side == "high") {
+      obs_adjusted <- obs + 1
+      test_statistic <- obs_adjusted * (1 - 1 / (9 * obs_adjusted) +
+                                          qnorm(0.5 + p / 2) / 3 / sqrt(obs_adjusted))^3
+    }
+  }
+
+  test_statistic <- test_statistic / expected
+  return(test_statistic)
+}
+
+#' Calculate the proportion funnel point value for a specific population based
+#' on a population average value
+#'
+#' Returns a value equivalent to the higher/lower funnel plot point based on the
+#' input population and probability
+#'
+#' @param p numeric (between 0 and 1); probability to calculate funnel plot
+#'   point (will normally be either 0.975 or 0.999)
+#' @param population numeric; the population for the area
+#' @param average_proportion numeric; the average proportion for all the areas
+#'   included in the funnel plot (the sum of the numerators divided by the sum
+#'   of the denominators)
+#' @param side string; "low" or "high" to determine which funnel to calculate
+#' @param multiplier  numeric; the multiplier used to express the final values
+#'   (eg 100 = percentage); default 100
+#' @return returns a value equivalent to the specified funnel plot point for the
+#'   input population
+#'
+#' @noRd
+#'
+#' @author Sebastian Fox, \email{sebastian.fox@@phe.gov.uk}
+#'
+
+sigma_adjustment <- function(p, population, average_proportion, side, multiplier) {
+  first_part <- average_proportion * (population /
+                                        qnorm(p)^2 + 1)
+
+  adj <- sqrt((-8 * average_proportion * (population /
+                                            qnorm(p)^2 + 1))^2 - 64 *
+                (1 / qnorm(p)^2 + 1 / population) *
+                average_proportion * (population *
+                                        (average_proportion * (population /
+                                                                 qnorm(p)^2 + 2) - 1) +
+                                        qnorm(p)^2 *
+                                        (average_proportion - 1)))
+
+  last_part <- (1 / qnorm(p)^2 + 1 /
+                  population)
+
+  if (side == "low") {
+    adj_return <- (first_part - adj / 8) / last_part
+  } else if (side == "high") {
+    adj_return <- (first_part + adj / 8) / last_part
+  }
+  adj_return <- (adj_return /
+                   population) * multiplier
+  return(adj_return)
+}
+
